django-hotsauce-oauthclient
===========================

.. image:: docs/_static/oauth2.png

This module provides a simple WSGI middleware that requires the user to
authenticate via the specific `OAuth 2.0`_ service e.g. Facebook_, Google_,
GitHub_.

You can install the package via downloading from PyPI_:

.. code-block:: console

   $ pip install django-hotsauce-oauthclient

Read the documentation as well.

.. _OAuth 2.0: http://oauth.net/2/
.. _Facebook: http://www.facebook.com/
.. _Google: http://www.google.com/
.. _GitHub: https://github.com/
.. _PyPI: https://pypi.python.org/pypi/django-hotsauce-oauthclient